@@ -4,29 +4,26 @@
 """
 
 """
-import abc
+#  import abc
 import pygments
 
-from pygments.token import Token
+#  from pygments.token import Token
 from pygments.lexers.python import PythonLexer
 from prompt_toolkit.formatted_text import PygmentsTokens
 from prompt_toolkit import print_formatted_text
 
-from wpy.argument import CommandArgumentParser
+from csarg import CommandArgumentParser
 
 from wush.common.loggers import create_logger
+from wush.common.run_mode import RUN_MODE
 from wush.config import load_config
 
 class CmdArgumentParser(CommandArgumentParser):
     logger = create_logger('CmdArgumentParser')
-    prompt_session = None
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.config = load_config()
 
-    def set_prompt_session(self, client):
-        self.prompt_session = client
 
     def get_completions_after_argument(self, word_for_completion):
         """
@@ -65,3 +62,16 @@ class CmdArgumentParser(CommandArgumentParser):
         tokens = list(pygments.lex(text, lexer=PythonLexer()))
         print_formatted_text(PygmentsTokens(tokens), end='')
 
+    def run(self, args):
+        self.config = load_config()
+        func_name = f'run_{RUN_MODE.mode}'
+        func = None
+        if hasattr(self, func_name):
+            func = getattr(self, func_name)
+        else:
+            # 如果没有提供模式专用函数，则使用默认 run 方法
+            if not hasattr(self, 'run'):
+                raise RuntimeError('找不到参数运行方法')
+            func = getattr(self, 'run')
+
+        func(args)
