@@ -5,17 +5,19 @@
 run 命令的参数解析
 """
 import os
-from wpy.argument import Action
-from wpy.argument import CommandArgumentParserFactory
+from csarg import Action
+from csarg import CommandArgumentParserFactory
 
 from wush.common import utils
 from wush.common.constants import Constants
 from wush.common.utils import run_shell
 from wush.common.loggers import create_logger
 from wush.common.run_mode import RUN_MODE
+from wush.common.config_value import environ_keys
 from wush.config import load_config
 from wush.web.request import RequestClient
 from wush.web.request import RequestBuilder
+from wush.web.response import ResponseHandler
 from wush.web.history import History
 
 from .command import CmdArgumentParser
@@ -36,10 +38,14 @@ class RunArgumentParser(CmdArgumentParser):
         item.add_argument('-m', '--module', help='模块名称')
         item.add_argument('-s', '--space', help='空间名称')
         item.add_argument('-n', '--name', help='请求名称')
+        item.add_argument('-c', '--config', help='配置地址')
+        item.add_argument('--attr', help='属性信息，自定义')
         item.add_argument('--params', action = Action.APPEND.value,
             help='请求地址参数')
         item.add_argument('--json', action = Action.APPEND.value,
             help='请求 body 参数，json 格式')
+        item.add_argument('--env', action = Action.APPEND.value,
+            help='传递环境变量')
         item.add_argument('--open', action = Action.STORE_TRUE.value,
             help = '是否通过浏览器打开请求结果')
         item.add_argument('--curl', action = Action.STORE_TRUE.value,
@@ -47,10 +53,16 @@ class RunArgumentParser(CmdArgumentParser):
         item.add_argument('--with-browser-cookie',
             action = Action.STORE_TRUE.value,
             help = '是否使用 curl 文本')
+        item.add_argument('--no-handle-response',
+            action = Action.STORE_TRUE.value,
+            help = '不对 response 做处理')
+        item.add_argument('--no-browser',
+            action = Action.STORE_TRUE.value,
+            help = '不使用浏览器打开结果页面')
         if RUN_MODE.is_command:
             item.add_argument('--url', help='请求地址')
 
-        item.config = load_config()
+        #  item.config = load_config()
 
         return item
 
@@ -59,6 +71,7 @@ class RunArgumentParser(CmdArgumentParser):
         获取补全的单词列表
         :param word_for_completion: 补全需要的单词
         """
+        self.config = load_config()
         words = []
         if not self.argument:
             return words
@@ -85,10 +98,24 @@ class RunArgumentParser(CmdArgumentParser):
             request = self.config.get_request(arg.module, arg.name)
             words = self._dict_to_completions(request.json.to_dict())
             return words
+        elif word_for_completion == '--env':
+            # 环境变量
+            # 使用当前请求的环境变量 keys 做补全
+            request = self.config.get_request(arg.module, arg.name,
+                    set_env=False)
+            keys = environ_keys(request)
+            self.logger.info(request.path)
+            self.logger.info(
+                f'request {arg.module} {arg.name} environ_keys {keys}')
+            data = { f"{o}": "" for o in keys }
+
+            words = self._dict_to_completions(data)
+            return words
 
         return super().get_completions_after_argument(word_for_completion)
 
     def _dict_to_completions(self, data):
+        """字典转为自动补全信息"""
         words = []
         for k, v in data.items():
             words.append(dict(
@@ -97,10 +124,13 @@ class RunArgumentParser(CmdArgumentParser):
                 display_meta=''))
         return words
 
-    def _run_command(self, args):
+    def run_command(self, text):
         """运行命令行模式"""
+        self.config = load_config()
+        args = self.parse_args(text)
         # curl 模式下打开一个文件并输入文本供后续使用
         builder = RequestBuilder()
+        builder.set_run_mode(RUN_MODE.mode)
         if args.curl:
             filepath = Constants.build_tmpfile('curl')
             run_shell(f'echo "# 请输入 cUrl 文本\n" > {filepath}')
@@ -114,40 +144,42 @@ class RunArgumentParser(CmdArgumentParser):
 
         if args.name:
             builder = self._get_request_builder(args)
+        builder.argument = args
 
         self.logger.info('builder {}'.format(builder.to_dict()))
 
         req_client = RequestClient(builder)
         res = req_client.request()
-        res.print()
-        History().save(res)
+        self._run(args, builder, res)
 
     def _get_request_builder(self, args):
         """获取请求构造体"""
         params = utils.list_key_val_to_dict(args.params or [])
         json_data = utils.list_key_val_to_dict(args.json or [])
+        environs = utils.list_key_val_to_dict(args.env or [])
         self.logger.info('arg params %s', params)
         self.logger.info('arg json %s', json_data)
+        self.logger.info('arg env %s', environs)
 
-        request_model = self.config.get_request(args.module, args.name)
+        request_model = self.config.get_request(args.module, args.name,
+                environs = environs)
         request_model.add_params(**params)
-        # TODO 对 json 进行解析
+        request_model.add_json(**json_data)
 
         builder = RequestBuilder.loads_request_model(request_model,
             args.with_browser_cookie)
+        builder.argument = args
         return builder
 
-    def run(self, text):
+    def run_shell(self, text):
+        self.config = load_config()
         args = self.parse_args(text)
-        # 判断运行模式
-        if RUN_MODE.is_command:
-            self._run_command(args)
-            return
 
         if not args.name:
             raise Exception
 
         builder = self._get_request_builder(args)
+        builder.set_run_mode(RUN_MODE.mode)
         request_client = RequestClient(builder)
 
         self._print('Space: {}'.format(args.space))
@@ -162,17 +194,28 @@ class RunArgumentParser(CmdArgumentParser):
 
         self._print('Status: {}'.format(res.status_code))
 
+        self._run(args, builder, res)
+
+    def _run(self, args, builder, res):
+
+        # 保存历史记录
         History().save(res)
+
         if args.open:
             self._print('See in browser')
             self._open(builder.version)
-        else:
-            self.config.function.handler_response(
-                builder, res)
+            return
+
+        handler_func = ResponseHandler.get_handler(args.module,
+            args.name)
+        if handler_func and not args.no_handle_response:
+            handler_func(res)
+            return
+
+        self.config.function.handler_response( res)
 
     def _open(self, version):
         #  """打开请求信息"""
         port = self.config.server_port
         url = f"http://localhost:{port}/api/version/{version}"
-        # TODO 适配更多系统
-        os.system(f'open -a "/Applications/Google Chrome.app" "{url}"')
+        utils.open_url(url)
