@@ -8,18 +8,65 @@
 import json
 import os
 import re
+from functools import singledispatch
 
-from wpy.files import FileUtils
+from wpy.path import read_dict
 from wush.common.loggers import create_logger
 from wush.model import Model
 
+__all__ = ['environ_keys', 'ConfigValue']
+
+#  _REG_ENV = r'(\${.*?})'
+#  _REG_ENV = r'\{(.+?)\}'
+_REG_ENV2 = r'\${(.+?)\}'
+
+@singledispatch
+def environ_keys(text):
+    """获取环境变量 keys"""
+    return []
+
+@environ_keys.register(str)
+def _(text):
+    return set(re.findall(_REG_ENV2, text))
+
+@environ_keys.register(dict)
+def _(data):
+    res = set()
+    for key, value in data.items():
+        for name in environ_keys(key):
+            if name not in res:
+                res.add(name)
+        for name in environ_keys(value):
+            if name not in res:
+                res.add(name)
+    return res
+
+@environ_keys.register(list)
+def _(data):
+    res = set()
+    for line in data:
+        for name in environ_keys(line):
+            if name not in res:
+                res.add(name)
+    return res
+
+@environ_keys.register(Model)
+def _(model):
+    res = set()
+    for value in model.dict().values():
+        for name in environ_keys(value):
+            if name not in res:
+                res.add(name)
+    return res
+
 class ConfigValue():
     logger = create_logger('ConfigValue')
 
     def __init__(self, value):
         self.value = value
 
-        self.REG_ENV = r'(\${.*?})'
+        #  self.REG_ENV = r'(\${.*?})'
+        #  self.REG_ENV2 = r'({.*?})'
         self.REG_PARSE = r'(^\b(json|yml|xml)\b@.*?)'
         self.env = dict(os.environ)
         self.functions = {}
@@ -60,28 +107,6 @@ class ConfigValue():
 
         return value
 
-    #  @singledispatch
-    #  def _format(self, obj):
-        #  self.logger.info('type %s', type(obj))
-        #  return obj
-
-    #  @_format.register(dict)
-    #  def _(self, value):
-        #  """格式化字典"""
-        #  return self._format_dict(dict)
-
-    #  @_format.register(list)
-    #  def _(self, lines):
-        #  """格式化数组"""
-        #  self.logger.info('-' * 200)
-        #  return self._format_list(lines)
-
-    #  @_format.register(str)
-    #  def _(self, text):
-        #  """格式化字符窜"""
-        #  self.logger.info('-' * 200)
-        #  return self._format_str(text)
-
     def _format_dict(self, value):
         """格式化字典"""
         for v_k, v_v in value.items():
@@ -118,7 +143,7 @@ class ConfigValue():
             text = text[len(parse_type) + 1:]
             if self._is_file(text):
                 if parse_type == 'json':
-                    return FileUtils.read_dict(text)
+                    return read_dict(text)
             else:
                 if parse_type == 'json':
                     return json.loads(text)
@@ -135,14 +160,14 @@ class ConfigValue():
     def _format_file_content(self, filepath):
         '''格式化文件内容'''
         if filepath.endswith('.json') or filepath.endswith('.yml'):
-            return FileUtils.read_dict(filepath)
+            return read_dict(filepath)
 
         with open(filepath, 'r') as f:
             lines = f.readlines()
             if not lines:
                 return ''
             if lines[0].startswith('{') and lines[-1].endswith('}'):
-                return FileUtils.read_dict(filepath)
+                return read_dict(filepath)
             return ''.join(lines)
 
     def _is_file(self, filepath):
@@ -153,37 +178,49 @@ class ConfigValue():
         '''是否有环境变量'''
         if not isinstance(text, str):
             return False
-        lines = re.findall(self.REG_ENV, text)
-        self.environ_names = [o[2:-1] for o in lines]
+        self.environ_names = environ_keys(text)
         return True if self.environ_names else False
 
+    def _replace(self, match):
+        """正则替换方法"""
+        groups = match.groups()
+        if not groups:
+            return
+
+        k = groups[0]
+        if '(' not  in k and ')' not in k:
+            env_value = self.env.get(k, "")
+            if isinstance(env_value, dict) or isinstance(env_value, list):
+                return json.dumps(env_value)
+            return str(env_value)
+
+        k = k.strip(')').strip(' ')
+        func_name, args_str = k.split('(')
+        func = self.functions.get(func_name)
+        self.logger.info('func_name %s %s', func_name, func)
+
+        if not func:
+            return
+        if not args_str:
+            args_str = '()'
+        else:
+            args_str = '({},)'.format(args_str)
+        args = eval(args_str)
+        repl = func(*args)
+        repl = str(repl)
+        return repl
+
     def _format_environ(self, text):
         '''格式化环境变量'''
         if not self.environ_names:
             return text
 
-        self.logger.info('environ_names %s', self.environ_names)
-
-        for k in self.environ_names:
-            # 处理函数的执行和替换
-            orgl = '${' + k + '}'
-            if '(' in k and ')' in k:
-                k = k.strip(')').strip(' ')
-                func_name, args_str = k.split('(')
-                func = self.functions.get(func_name)
-                self.logger.info('func_name %s %s', func_name, func)
-
-                if not func:
-                    continue
-                if not args_str:
-                    args_str = '()'
-                else:
-                    args_str = '({},)'.format(args_str)
-                args = eval(args_str)
-                repl = func(*args)
-                repl = str(repl)
-                text = text.replace(orgl, repl)
-            else:
-                text = text.replace(orgl, self.env.get(k) or '')
+        text = re.sub(_REG_ENV2, self._replace, text)
+        #  text = re.sub(_REG_ENV, self._replace, text)
         return text
 
+if __name__ == "__main__":
+    text_value = {"name": "wxnacy"}
+    text = 'json@${text_value}'
+    data = ConfigValue(text).set_env(text_value = text_value).format()
+    assert data == {"name": "wxnacy"}
