@@ -6,13 +6,15 @@
 """
 import os
 import yaml
+import copy
 
-from wush.config.models import ConfigModel
-from wush.config.models import EnvModel
 from wush.common.config_value import ConfigValue
 from wush.common.constants import Constants
-from wush.config.function import load_super_function
 from wush.common.loggers import get_logger
+from wush.common.utils import load_module
+from wush.config.models import ConfigModel
+from wush.config.models import EnvModel
+from wush.config.function import load_function
 
 __all__ = ['load_config']
 
@@ -57,15 +59,20 @@ class Config(object):
         ins._config = ConfigModel(**data)
 
         # 对模块地址进行解析
+        if not ins._config.modules:
+            ins._config.modules = []
         for module_path in ins._config.iter_module_path():
             module = cls.read_yml(module_path)
             ins._config.modules.append(module)
 
         # 格式化模型
         ins._config.format()
+        # 加载插件模块
+        for module_name in ins._config.function_modules:
+            load_module(module_name)
 
         # 加载方法
-        ins._function = load_super_function()
+        ins._function = load_function()
 
         for key in ConfigModel.__all__:
             setattr(ins, key, getattr(ins._config, key))
@@ -92,18 +99,53 @@ class Config(object):
         """获取请求列表"""
         return self._config.get_module(module_name).requests
 
-    def get_request(self, module_name, request_name):
-        """获取请求模型"""
+    def get_request(self, module_name, request_name, set_env=True, environs=None):
+        """获取请求模型
+        :param bool set_env: 是否设置环境变量
+        :param dict environs: 编辑变量
+        """
         req = self._config.get_module(module_name).get_request(request_name)
+        req = copy.deepcopy(req)
         env = self._config.env.to_dict()
+        if isinstance(environs, dict):
+            env.update(environs)
         self.logger.info('config env {}'.format(env))
 
+        for key, value in env.items():
+            # 优先使用环境变量数据
+            env_value = os.getenv(key)
+            if env_value:
+                env[key] = env_value
+                continue
+            if not value:
+                continue
+            os.environ[key] = value
+
         # 将请求模型做环境变量格式化处理并返回
-        req = ConfigValue(req).set_env(**env).format()
+        if set_env:
+            req = ConfigValue(req).set_env(**env).set_functions(
+                **self.function.get_functions()).format()
         req.format()
         return req
 
+
+def _get_config_path(config_path=None):
+    """
+    获取配置地址
+    """
+    if config_path:
+        Config.logger.info('配置文件: 用户指定 {}'.format(config_path))
+        return config_path
+    if os.path.exists(Constants.CONFIG_PATH):
+        Config.logger.info('配置文件: 默认 {}'.format(Constants.CONFIG_PATH))
+        return Constants.CONFIG_PATH
+
+    config_path = Constants.get_sys_config_path()
+    Config.logger.info('配置文件: 系统 {}'.format(config_path))
+    return config_path
+
 _config = None
+_config_dict = {}
 
 def load_config(config_path = None):
     """加载配置
@@ -116,16 +158,10 @@ def load_config(config_path = None):
     """
     global _config
     if not _config:
-        if config_path:
-            _config = Config.load(config_path)
-        else:
-            if os.path.exists(Constants.CONFIG_PATH):
-                _config = Config.load(Constants.CONFIG_PATH)
-            else:
-                _config = Config.loads(yaml.safe_load(
-                    Constants.INIT_CONIFG_YML))
+        config_path = _get_config_path(config_path)
+        _config = Config.load(config_path)
 
     return _config
 
-if __name__ == "__main__":
-    config = load_config()
+#  if __name__ == "__main__":
+    #  config = load_config()
