@@ -6,6 +6,7 @@
 """
 
 import traceback
+import os
 import hashlib
 import json
 
@@ -14,12 +15,25 @@ from rich.table import Table
 from wpy.base import BaseFactory
 from wpy import randoms
 
+from wush.common import utils
 from wush.common.loggers import get_logger
+from wush.web.cookie import Cookie
 
 logger = get_logger('function')
 
+__all__ = ['FunctionFactory']
+
 class FunctionFactory(BaseFactory):
-    pass
+
+    @classmethod
+    def get_super_factory(cls):
+        factory = cls.get_factory()
+        _super_factory = {}
+        for key, value in factory.items():
+            module = value.__module__
+            if module.startswith('wush'):
+                _super_factory[key] = value
+        return _super_factory
 
 @FunctionFactory.register()
 def random_int(length, min_int=None, max_int=None):
@@ -42,8 +56,9 @@ def get_completion_words(word_for_completion):
     return []
 
 @FunctionFactory.register()
-def handler_response(request_builder, response):
-    print('Response:')
+def handler_response(response):
+    #  print('Response:')
+    # 判断是否为 html 结果
     try:
         data = response.json()
         data = json.dumps(data, indent=4, ensure_ascii=False)
@@ -51,6 +66,10 @@ def handler_response(request_builder, response):
         logger.error(traceback.format_exc())
         data = response.content
     print(data)
+    url = response.url
+    if response.is_html and not response.request_builder.argument.no_browser:
+        print('Html page see in browser')
+        utils.open_url(url)
 
 @FunctionFactory.register()
 def print_table(config):
@@ -81,6 +100,16 @@ def print_table(config):
     if after_table:
         console.print(after_table)
 
+@FunctionFactory.register()
+def get_browser_cookies(domains, cookie_name=None):
+    """
+    获取浏览器的 cookies
+    """
+    res = Cookie.get_browser_cookie(*domains) or {}
+    if cookie_name:
+        return res.get(cookie_name)
+    return res
+
 class Function(object):
     get_completion_words = None
     random_int = None
@@ -112,6 +141,17 @@ def load_super_function():
     """加载 super function"""
     global _super_function
     if not _super_function:
-        _super_function = Function(FunctionFactory.get_factory())
+        _super_function = Function(FunctionFactory.get_super_factory())
     return _super_function
 
+
+_function = None
+def load_function():
+    """加载全部 function"""
+    global _function
+    if not _function:
+        _function = Function(FunctionFactory.get_factory())
+    return _function
+
+if __name__ == "__main__":
+    pass
