@@ -5,9 +5,11 @@
 配置模型
 """
 import os
+#  from collections import defaultdict
 
 from wpy.base import BaseObject
 
+from wush.common.config_value import ConfigValue
 from wush.common.constants import Constants
 from wush.common.loggers import get_logger
 from wush.model import datatype
@@ -17,7 +19,29 @@ from wush.web.enums import ProtocolEnum
 
 logger = get_logger('config.models')
 
+class BaseModel(BaseObject):
+
+    def inherit(self, super_ins, keys):
+        """继承数据"""
+        for key in keys:
+            super_value = getattr(super_ins, key)
+            sub_value = getattr(self, key)
+            if not sub_value:
+                setattr(self, key, super_value)
+            else:
+                # 字段结构进行拼接
+                if isinstance(super_value, dict):
+                    super_value = dict(super_value)
+                    super_value.update(sub_value)
+                # 列表结构进行拼接
+                if isinstance(super_value, list):
+                    super_value = list(super_value)
+                    super_value.extend(sub_value)
+
+                #  setattr(self, key, super_value)
+
 class EnvModel(BaseObject):
+    _default = None
 
     def __init__(self, **kwargs):
         # 将数字类型转为字符串
@@ -30,6 +54,16 @@ class EnvModel(BaseObject):
             #  setattr(self, k, v)
         super().__init__(**kwargs)
 
+    @classmethod
+    def default(cls):
+        """使用默认环境变量
+
+        """
+        _env = {}
+        if not cls._default:
+            cls._default = cls(**_env)
+        return cls._default
+
 class FieldModel(Model):
     """配置字段
     在配置中，单一值无法描述字段时，可以使用该模型
@@ -46,6 +80,7 @@ class AutoFieldModel(Model):
     AUTO_FORMAT = True
     DEFAULT_DATATYPE = datatype.Object(model = FieldModel)
 
+
     def __init__(self, **kwargs):
         """对数据进行前置过滤"""
         for k, v in kwargs.items():
@@ -80,12 +115,8 @@ class AutoFieldModel(Model):
             v = { "_value": v, "_data_type": type(v) }
         return v
 
-    #  def __setattr__(self, key, value):
-        #  value = self._format_value(value)
-        #  super().__setattr__(key, value)
 
-
-class RequestModel(Model):
+class RequestModel(Model, BaseModel):
     """请求配置模型"""
     AUTO_FORMAT = True
 
@@ -115,8 +146,19 @@ class RequestModel(Model):
             setattr(self.params, k, v)
         self.params.format()
 
+    def add_json(self, **kwargs):
+        """添加 params 参数"""
+        for k, v in kwargs.items():
+            origin_value = None
+            if hasattr(self.json, k):
+                origin_value = getattr(self.json, k)
+                v = origin_value._data_type(v)
+            v = self.json._format_value(v)
+            setattr(self.json, k, v)
+        self.json.format()
 
-class ModuleModel(Model):
+
+class ModuleModel(Model, BaseModel):
     AUTO_FORMAT = True
 
     name = datatype.Str()
@@ -132,6 +174,8 @@ class ModuleModel(Model):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        for req in self.requests:
+            logger.info('test %s', req.to_dict())
         self.__req__ = {o.name: o for o in self.requests}
 
     def get_request(self, name):
@@ -141,22 +185,7 @@ class ModuleModel(Model):
             # 继承 module 的字段
             inherit_keys = ('protocol', 'domain', 'cookies', 'headers',
                 'cookie_domains')
-            for key in inherit_keys:
-                super_value = getattr(self, key)
-                sub_value = getattr(req, key)
-                if not sub_value:
-                    setattr(req, key, super_value)
-                else:
-                    # 字段结构进行拼接
-                    if isinstance(super_value, dict):
-                        super_value = dict(super_value)
-                        super_value.update(sub_value)
-                    # 列表结构进行拼接
-                    if isinstance(super_value, list):
-                        super_value = list(super_value)
-                        super_value.extend(sub_value)
-
-                    setattr(req, key, super_value)
+            req.inherit(self, inherit_keys)
 
             # 拼装 url
             if not req.url:
@@ -166,12 +195,17 @@ class ModuleModel(Model):
 
 class ConfigModel(Model):
     """客户端全局配置模型"""
-    __all__ = ['api_history_dir','server_port']
+    __all__ = ['api_history_dir','server_port', 'server_host']
 
     modules = datatype.List(model = ModuleModel)
     env = datatype.Object(model = EnvModel)
+    cookies = datatype.Dict()
+    headers = datatype.Dict()
+    cookie_domains = datatype.List()                # 获取 cookie 的域名列表
     modules_include = datatype.List()
+    function_modules = datatype.List()
     server_port = datatype.Str(default = Constants.SERVER_PORT)
+    server_host = datatype.Str(default = Constants.SERVER_HOST)
     api_history_dir = datatype.Str(default = Constants.API_HISTORY_DIR)
 
     def format(self):
@@ -179,6 +213,12 @@ class ConfigModel(Model):
         先进行 modules 处理
         """
         super().format()
+        # 对变量进行格式化
+        default_env = EnvModel.default()
+        for i, _module in enumerate(self.function_modules):
+            self.function_modules[i] = ConfigValue(_module
+                ).set_env(**default_env.to_dict()).format()
+        #  ConfigValue(self).format()
         self.__mod__ = {o.name: o for o in self.modules}
 
     def get_module(self, name):
@@ -186,6 +226,10 @@ class ConfigModel(Model):
         if not self.__is_format__:
             raise Exception('ConfigModel must format first')
         module = self.__mod__.get(name)
+        if module:
+            inherit_keys = ['headers', 'cookies', 'cookie_domains']
+            module.inherit(self, inherit_keys)
+
         return module
 
     @classmethod
